@@ -26,8 +26,8 @@ class AreEqual(FormValidator):
 
     """
     message = u'The {0} doesn\'t match.'
-    
-    def __init__(self, name1, name2, plural=u'fields', message=None):
+
+    def __init__(self, name1, name2, message=None, plural=u'fields'):
         self.name1 = name1
         self.name2 = name2
         if message is None:
@@ -50,7 +50,7 @@ class AtLeastOne(FormValidator):
 
     """
     message = u'Fill at least one of these fields.'
-    
+
     def __init__(self, fields, message=None):
         self.fields = fields
         if message is not None:
